==> mgb-0.5.4.3-de.zip: mgb-0.5.4.3-de/admin.php <==
<?php
	/*
	MGB 0.5.4.3
	Copyright (C) 2004 - 2006  Juergen Grueneisl

	This program is free software; you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation; either version 2 of the License, or
	(at your option) any later version.

	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.
	*/

         include "settings.php";
         include "language/lang_admin.php";

         if($_GET[sid]!=$settings['passwort'])
         	{
                 $ausgabe="<br>\n";
                 $ausgabe.="<br>\n";
                 $ausgabe.="<center>\n";
                 $ausgabe.="<table summary='admin' cellspacing='0' cellpadding='2' class='passwort'>\n";
                 $ausgabe.="<tr>\n";
         	$ausgabe.="<td class='passworteingabetitel' style='height:20px'><font class='passworteingabetitel'>".$lang['failure']."</font></td>\n";
                 $ausgabe.="</tr>\n";
                 $ausgabe.="<tr>\n";
         	$ausgabe.="<td class='passworteingabe'>\n";
                 $ausgabe.="<center>\n";
                 $ausgabe.="<br><center><font class='passwort_fehler'>".$lang['not_logged_in']."</font></center><br>";
                 $ausgabe.="</center>\n";
                 $ausgabe.="</td>\n";
                 $ausgabe.="</tr>\n";
                 $ausgabe.="</table>\n";
                 $ausgabe.="<br>\n";
                 $ausgabe.="<br>\n";
                 $ausgabe.="</center>\n";
                 $refresh="<meta http-equiv='refresh' content='2; URL=passwort.php'>";
                 }
         else
         	{
         	if($_GET[action]=="edit")
         		{
                 	$iframesrc="editsettings.php?sid=".$_GET[sid];
                 	}
         	if($_GET[action]=="activate")
         		{
                 	$iframesrc="activate.php?sid=".$_GET[sid];
                 	}
         	if($_GET[action]=="deactivate")
         		{
                 	$iframesrc="deactivate.php?sid=".$_GET[sid];
                 	}
                 if($_GET[action]=="delete")
         		{
                 	$iframesrc="delete.php?sid=".$_GET[sid];
                 	}
                 if($_GET[action]=="comment")
         		{
                 	$iframesrc="comment.php?sid=".$_GET[sid];
                 	}
         	elseif($_GET[action]=="")
         		{
                 	$iframesrc="editsettings.php?sid=".$_GET[sid];
                 	}

                 $ausgabe="<center>\n";
		$ausgabe.="<br><br>\n";
		$ausgabe.="<table summary='admin' class='admin_rahmen' cellspacing='0' cellpadding='0'>\n";
		$ausgabe.="<tr>\n";
         	$ausgabe.="<td class='admin_rahmennavigation'>\n";
                 $ausgabe.="<center>\n";
                 $ausgabe.="<table summary='admin' class='admin_navigation' cellspacing='0' cellpadding='2'>";
                 $ausgabe.="<tr>\n";
         	$ausgabe.="<td class='admin_navigationtitel' style='height:20px'><font class='admin'>&nbsp;</font></td>\n";
                 $ausgabe.="</tr>\n";
                 $ausgabe.="<tr>\n";
         	$ausgabe.="<td onMouseOver=\"style.backgroundColor='#9F9F9F'; style.color='#CFCFCF';\" onMouseOut=\"style.backgroundColor='#CFCFCF'; style.color='#9F9F9F'\" class='navigation'><font class='admin'>::.&nbsp;<a class='admin_navigation' href='admin.php?action=edit&amp;sid=".$_GET[sid]."'>".$lang['navi_settings']."</a></font></td>\n";
                 $ausgabe.="</tr>\n";
                 $ausgabe.="<tr>\n";
         	$ausgabe.="<td onMouseOver=\"style.backgroundColor='#9F9F9F'; style.color='#CFCFCF';\" onMouseOut=\"style.backgroundColor='#CFCFCF'; style.color='#9F9F9F'\" class='navigation'><font class='admin'>::.&nbsp;<a class='admin_navigation' href='admin.php?action=activate&amp;sid=".$_GET[sid]."'>".$lang['navi_activate']."</a></font></td>\n";
                 $ausgabe.="</tr>\n";
                 $ausgabe.="<tr>\n";
         	$ausgabe.="<td onMouseOver=\"style.backgroundColor='#9F9F9F'; style.color='#CFCFCF';\" onMouseOut=\"style.backgroundColor='#CFCFCF'; style.color='#9F9F9F'\" class='navigation'><font class='admin'>::.&nbsp;<a class='admin_navigation' href='admin.php?action=deactivate&amp;sid=".$_GET[sid]."'>".$lang['navi_deactivate']."</a></font></td>\n";
                 $ausgabe.="</tr>\n";
                 $ausgabe.="<tr>\n";
         	$ausgabe.="<td onMouseOver=\"style.backgroundColor='#9F9F9F'; style.color='#CFCFCF';\" onMouseOut=\"style.backgroundColor='#CFCFCF'; style.color='#9F9F9F'\" class='navigation'><font class='admin'>::.&nbsp;<a class='admin_navigation' href='admin.php?action=delete&amp;sid=".$_GET[sid]."'>".$lang['navi_delete']."</a></font></td>\n";
                 $ausgabe.="</tr>\n";
                 $ausgabe.="<tr>\n";
         	$ausgabe.="<td onMouseOver=\"style.backgroundColor='#9F9F9F'; style.color='#CFCFCF';\" onMouseOut=\"style.backgroundColor='#CFCFCF'; style.color='#9F9F9F'\" class='navigation'><font class='admin'>::.&nbsp;<a class='admin_navigation' href='admin.php?action=comment&amp;sid=".$_GET[sid]."'>".$lang['navi_comment']."</a></font></td>\n";
                 $ausgabe.="</tr>\n";
                 $ausgabe.="<tr>\n";
         	$ausgabe.="<td onMouseOver=\"style.backgroundColor='#9F9F9F'; style.color='#CFCFCF';\" onMouseOut=\"style.backgroundColor='#CFCFCF'; style.color='#9F9F9F'\" class='navigation'><font class='admin'>::.&nbsp;<a class='admin_navigation' href='onlinehilfe/index.html' target='_blank'>".$lang['navi_onlinehelp']."</a></font></td>\n";
                 $ausgabe.="</tr>\n";
                 $ausgabe.="</table>\n";
                 $ausgabe.="<br>\n";
                 if($settings['howtoopenadminwindow']==0)
                 	{
                 	$ausgabe.="<table summary='admin' cellspacing='0' cellpadding='2' class='admin_navigation'>\n";
                 	$ausgabe.="<tr>\n";
         		$ausgabe.="<td class='admin_navigationtitel' style='height:20px'><font class='admin'>&nbsp;</font></td>\n";
                 	$ausgabe.="</tr>\n";
                 	$ausgabe.="<tr>\n";
         		$ausgabe.="<td onMouseOver=\"style.backgroundColor='#9F9F9F'; style.color='#CFCFCF';\" onMouseOut=\"style.backgroundColor='#CFCFCF'; style.color='#9F9F9F'\" class='admin_navigation'><font class='admin'>::.&nbsp;<a class='admin_navigation' href='guestbook.php'>".$lang['navi_back']."</a></font></td>\n";
                 	$ausgabe.="</tr>\n";
                 	$ausgabe.="</table>\n";
                         }
                 $ausgabe.="</center>\n";
                 $ausgabe.="</td>\n";
                 $ausgabe.="<td class='admin_rahmeniframe'>\n";
                 $ausgabe.="<table summary='admin' class='admin_frame' cellspacing='0' cellpadding='2'>\n";
                 $ausgabe.="<tr>\n";
         	$ausgabe.="<td class='admin_navigationtitel' style='height:20px'><font class='admin'>&nbsp;</font></td>\n";
                 $ausgabe.="</tr>\n";
                 $ausgabe.="<tr>\n";
         	$ausgabe.="<td class='admin_frame'>\n";
                 $ausgabe.="<table summary='admin' class='admin_frame2'>\n";
                 $ausgabe.="<tr>\n";
                 $ausgabe.="<td class='admin_frame'>\n";
                 $ausgabe.="<iframe frameborder='0' src='".$iframesrc."'></iframe>\n";
                 $ausgabe.="</td>\n";
                 $ausgabe.="</tr>\n";
                 $ausgabe.="</table>\n";
                 $ausgabe.="</tr>\n";
                 $ausgabe.="</table>\n";
                 $ausgabe.="</td>\n";
         	$ausgabe.="</tr>\n";
		$ausgabe.="</table>\n";
                 $ausgabe.="</center>\n";
                 }
?>
<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.01 Transitional//EN">
<html>
<head>
<link rel="stylesheet" type="text/css" href="css/admin.css">
<title>Administration / Passworteingabe - guestbook v.null.f&uuml;nf by mopzz.de</title>
<meta name="author" content="mopzz">
<meta name="keywords" content="mgb.v.null.fuenf, mopzz.de, kostenloses g&auml;stebuch, kostenloses php g&auml;stebuch">
<!-- DO NOT REMOVE THIS COPYRIGHT -->
<meta name="description" content="MGB 0.5.4.3  Copyright 2006 by mopzz -- http://www.tv-kritik.net/mgb/index.php">
<!-- DO NOT REMOVE THIS COPYRIGHT -->
<meta http-equiv="content-type" content="text/html; charset=ISO-8859-1">
<?php echo $refresh; ?>
</head>
<body>
<?php
	echo $ausgabe;
	include "copyright.php";
?>
</body>
</html>

==> mgb-0.5.4.5-de.zip: mgb-0.5.4.5-de/admin.php <==
<?php
	/*
	MGB 0.5.4.5
	Copyright (C) 2004 - 2006  Juergen Grueneisl

	This program is free software; you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation; either version 2 of the License, or
	(at your option) any later version.

	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.
	*/

         include "settings.php";
         include "language/lang_admin.php";

         if($_GET[sid]!=$settings['passwort'])
         	{
                 $ausgabe="<br>\n";
                 $ausgabe.="<br>\n";
                 $ausgabe.="<center>\n";
                 $ausgabe.="<table summary='admin' cellspacing='0' cellpadding='2' class='passwort'>\n";
                 $ausgabe.="<tr>\n";
         	$ausgabe.="<td class='passworteingabetitel' style='height:20px'><font class='passworteingabetitel'>".$lang['failure']."</font></td>\n";
                 $ausgabe.="</tr>\n";
                 $ausgabe.="<tr>\n";
         	$ausgabe.="<td class='passworteingabe'>\n";
                 $ausgabe.="<center>\n";
                 $ausgabe.="<br><center><font class='passwort_fehler'>".$lang['not_logged_in']."</font></center><br>";
                 $ausgabe.="</center>\n";
                 $ausgabe.="</td>\n";
                 $ausgabe.="</tr>\n";
                 $ausgabe.="</table>\n";
                 $ausgabe.="<br>\n";
                 $ausgabe.="<br>\n";
                 $ausgabe.="</center>\n";
                 $refresh="<meta http-equiv='refresh' content='2; URL=passwort.php'>";
                 }
         else
         	{
         	if($_GET[action]=="edit")
         		{
                 	$iframesrc="editsettings.php?sid=".$_GET[sid];
                 	}
         	if($_GET[action]=="activate")
         		{
                 	$iframesrc="activate.php?sid=".$_GET[sid];
                 	}
         	if($_GET[action]=="deactivate")
         		{
                 	$iframesrc="deactivate.php?sid=".$_GET[sid];
                 	}
                 if($_GET[action]=="delete")
         		{
                 	$iframesrc="delete.php?sid=".$_GET[sid];
                 	}
                 if($_GET[action]=="comment")
         		{
                 	$iframesrc="comment.php?sid=".$_GET[sid];
                 	}
         	elseif($_GET[action]=="")
         		{
                 	$iframesrc="editsettings.php?sid=".$_GET[sid];
                 	}

                 $ausgabe="<center>\n";
		$ausgabe.="<br><br>\n";
		$ausgabe.="<table summary='admin' class='admin_rahmen' cellspacing='0' cellpadding='0'>\n";
		$ausgabe.="<tr>\n";
         	$ausgabe.="<td class='admin_rahmennavigation'>\n";
                 $ausgabe.="<center>\n";
                 $ausgabe.="<table summary='admin' class='admin_navigation' cellspacing='0' cellpadding='2'>";
                 $ausgabe.="<tr>\n";
         	$ausgabe.="<td class='admin_navigationtitel' style='height:20px'><font class='admin'>&nbsp;</font></td>\n";
                 $ausgabe.="</tr>\n";
                 $ausgabe.="<tr>\n";
         	$ausgabe.="<td onMouseOver=\"style.backgroundColor='#9F9F9F'; style.color='#CFCFCF';\" onMouseOut=\"style.backgroundColor='#CFCFCF'; style.color='#9F9F9F'\" class='navigation'><font class='admin'>::.&nbsp;<a class='admin_navigation' href='admin.php?action=edit&amp;sid=".$_GET[sid]."'>".$lang['navi_settings']."</a></font></td>\n";
                 $ausgabe.="</tr>\n";
                 $ausgabe.="<tr>\n";
         	$ausgabe.="<td onMouseOver=\"style.backgroundColor='#9F9F9F'; style.color='#CFCFCF';\" onMouseOut=\"style.backgroundColor='#CFCFCF'; style.color='#9F9F9F'\" class='navigation'><font class='admin'>::.&nbsp;<a class='admin_navigation' href='admin.php?action=activate&amp;sid=".$_GET[sid]."'>".$lang['navi_activate']."</a></font></td>\n";
                 $ausgabe.="</tr>\n";
                 $ausgabe.="<tr>\n";
         	$ausgabe.="<td onMouseOver=\"style.backgroundColor='#9F9F9F'; style.color='#CFCFCF';\" onMouseOut=\"style.backgroundColor='#CFCFCF'; style.color='#9F9F9F'\" class='navigation'><font class='admin'>::.&nbsp;<a class='admin_navigation' href='admin.php?action=deactivate&amp;sid=".$_GET[sid]."'>".$lang['navi_deactivate']."</a></font></td>\n";
                 $ausgabe.="</tr>\n";
                 $ausgabe.="<tr>\n";
         	$ausgabe.="<td onMouseOver=\"style.backgroundColor='#9F9F9F'; style.color='#CFCFCF';\" onMouseOut=\"style.backgroundColor='#CFCFCF'; style.color='#9F9F9F'\" class='navigation'><font class='admin'>::.&nbsp;<a class='admin_navigation' href='admin.php?action=delete&amp;sid=".$_GET[sid]."'>".$lang['navi_delete']."</a></font></td>\n";
                 $ausgabe.="</tr>\n";
                 $ausgabe.="<tr>\n";
         	$ausgabe.="<td onMouseOver=\"style.backgroundColor='#9F9F9F'; style.color='#CFCFCF';\" onMouseOut=\"style.backgroundColor='#CFCFCF'; style.color='#9F9F9F'\" class='navigation'><font class='admin'>::.&nbsp;<a class='admin_navigation' href='admin.php?action=comment&amp;sid=".$_GET[sid]."'>".$lang['navi_comment']."</a></font></td>\n";
                 $ausgabe.="</tr>\n";
                 $ausgabe.="<tr>\n";
         	$ausgabe.="<td onMouseOver=\"style.backgroundColor='#9F9F9F'; style.color='#CFCFCF';\" onMouseOut=\"style.backgroundColor='#CFCFCF'; style.color='#9F9F9F'\" class='navigation'><font class='admin'>::.&nbsp;<a class='admin_navigation' href='onlinehilfe/index.html' target='_blank'>".$lang['navi_onlinehelp']."</a></font></td>\n";
                 $ausgabe.="</tr>\n";
                 $ausgabe.="</table>\n";
                 $ausgabe.="<br>\n";
                 if($settings['howtoopenadminwindow']==0)
                 	{
                 	$ausgabe.="<table summary='admin' cellspacing='0' cellpadding='2' class='admin_navigation'>\n";
                 	$ausgabe.="<tr>\n";
         		$ausgabe.="<td class='admin_navigationtitel' style='height:20px'><font class='admin'>&nbsp;</font></td>\n";
                 	$ausgabe.="</tr>\n";
                 	$ausgabe.="<tr>\n";
         		$ausgabe.="<td onMouseOver=\"style.backgroundColor='#9F9F9F'; style.color='#CFCFCF';\" onMouseOut=\"style.backgroundColor='#CFCFCF'; style.color='#9F9F9F'\" class='admin_navigation'><font class='admin'>::.&nbsp;<a class='admin_navigation' href='guestbook.php'>".$lang['navi_back']."</a></font></td>\n";
                 	$ausgabe.="</tr>\n";
                 	$ausgabe.="</table>\n";
                         }
                 $ausgabe.="</center>\n";
                 $ausgabe.="</td>\n";
                 $ausgabe.="<td class='admin_rahmeniframe'>\n";
                 $ausgabe.="<table summary='admin' class='admin_frame' cellspacing='0' cellpadding='2'>\n";
                 $ausgabe.="<tr>\n";
         	$ausgabe.="<td class='admin_navigationtitel' style='height:20px'><font class='admin'>&nbsp;</font></td>\n";
                 $ausgabe.="</tr>\n";
                 $ausgabe.="<tr>\n";
         	$ausgabe.="<td class='admin_frame'>\n";
                 $ausgabe.="<table summary='admin' class='admin_frame2'>\n";
                 $ausgabe.="<tr>\n";
                 $ausgabe.="<td class='admin_frame'>\n";
                 $ausgabe.="<iframe frameborder='0' src='".$iframesrc."'></iframe>\n";
                 $ausgabe.="</td>\n";
                 $ausgabe.="</tr>\n";
                 $ausgabe.="</table>\n";
                 $ausgabe.="</tr>\n";
                 $ausgabe.="</table>\n";
                 $ausgabe.="</td>\n";
         	$ausgabe.="</tr>\n";
		$ausgabe.="</table>\n";
                 $ausgabe.="</center>\n";
                 }
?>
<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.01 Transitional//EN">
<html>
<head>
<link rel="stylesheet" type="text/css" href="css/admin.css">
<title>Administration - MGB 0.5.4.5</title>
<meta name="author" content="mopzz">
<meta name="keywords" content="mgb.v.null.fuenf, mopzz.de, kostenloses g&auml;stebuch, kostenloses php g&auml;stebuch">
<meta name="description" content="Administration des MGB">
<meta name="robots" content="noindex,nofollow">
<!-- DO NOT REMOVE THIS COPYRIGHT -->
<meta name="copyright" content="MGB 0.5.4.5  Copyright 2004-2006 by mopzz -- http://www.tv-kritik.net/mgb/index.php">
<!-- DO NOT REMOVE THIS COPYRIGHT -->
<meta http-equiv="content-type" content="text/html; charset=ISO-8859-1">
<?php echo $refresh; ?>
</head>
<body>
<?php
	echo $ausgabe;
	include "copyright.php";
?>
</body>
</html>
